Rev 3990: Fix failing test. in file:///net/bigmamac/Volumes/home/vila/src/bzr/bugs/httplib-broken-readline/

Vincent Ladeuil v.ladeuil+lp at free.fr
Tue Feb 10 08:52:56 GMT 2009


At file:///net/bigmamac/Volumes/home/vila/src/bzr/bugs/httplib-broken-readline/

------------------------------------------------------------
revno: 3990
revision-id: v.ladeuil+lp at free.fr-20090210085255-r75icw1wo30l4ua4
parent: v.ladeuil+lp at free.fr-20090209182543-nb0220ksr5xa20pg
committer: Vincent Ladeuil <v.ladeuil+lp at free.fr>
branch nick: httplib-broken-readline
timestamp: Tue 2009-02-10 09:52:55 +0100
message:
  Fix failing test.
  
  * bzrlib/tests/test_http.py:
  (TestHTTPRedirections.test_read_redirected_bundle_from_url): Don't
  use read_bundle_from_url since it's deprecated,sigh.
-------------- next part --------------
=== modified file 'bzrlib/tests/test_http.py'
--- a/bzrlib/tests/test_http.py	2009-01-30 00:49:41 +0000
+++ b/bzrlib/tests/test_http.py	2009-02-10 08:52:55 +0000
@@ -1258,10 +1258,11 @@
         self.assertEqual('0123456789', t.get('a').read())
 
     def test_read_redirected_bundle_from_url(self):
-        from bzrlib.bundle import read_bundle_from_url
+        from bzrlib.bundle import read_mergeable_from_url
         url = self.old_transport.abspath('bundle')
-        bundle = read_bundle_from_url(url)
-        # If read_bundle_from_url was successful we get an empty bundle
+        bundle = read_mergeable_from_url(
+            url, possible_transports=[self.old_transport])
+        # If read_mergeable_from_url was successful we get an empty bundle
         self.assertEqual([], bundle.revisions)
 
 



More information about the bazaar-commits mailing list